==> jc-1.4.0.tar.gz: javax/xml/transform/sax/SAXResult.h <==
// public class javax.xml.transform.sax.SAXResult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 66f2cec6461d7dc4 javax_xml_transform_sax_SAXResult

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_sax_SAXResult_H_
#define _JC_javax_xml_transform_sax_SAXResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_ContentHandler$object;
struct _jc_org_xml_sax_ext_LexicalHandler$object;

// Typedefs
typedef struct _jc_javax_xml_transform_sax_SAXResult$sub_refs	_jc_javax_xml_transform_sax_SAXResult$sub_refs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs	_jc_javax_xml_transform_sax_SAXResult$sub_nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$refs	_jc_javax_xml_transform_sax_SAXResult$refs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$nonrefs	_jc_javax_xml_transform_sax_SAXResult$nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$object	_jc_javax_xml_transform_sax_SAXResult$object;

typedef struct _jc_javax_xml_transform_sax_SAXResult$fields_struct	_jc_javax_xml_transform_sax_SAXResult$fields_struct;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vmethods	_jc_javax_xml_transform_sax_SAXResult$vmethods;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vtable	_jc_javax_xml_transform_sax_SAXResult$vtable;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vtype	_jc_javax_xml_transform_sax_SAXResult$vtype;

// Class fields structure
struct _jc_javax_xml_transform_sax_SAXResult$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
};
extern _jc_javax_xml_transform_sax_SAXResult$fields_struct _jc_javax_xml_transform_sax_SAXResult$class_fields;

// Constructors
extern void _jc_javax_xml_transform_sax_SAXResult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
extern void _jc_javax_xml_transform_sax_SAXResult$method$_init$f0c7c6098856f091(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXResult$method$getHandler$4982bcff61d71265(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXResult$method$getLexicalHandler$72221ad14c43ddef(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_sax_SAXResult$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
extern void _jc_javax_xml_transform_sax_SAXResult$method$setHandler$73980f3327e1b840(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *);
extern void _jc_javax_xml_transform_sax_SAXResult$method$setLexicalHandler$116d9e866e5271e3(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *);
extern void _jc_javax_xml_transform_sax_SAXResult$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getHandler$4982bcff61d71265;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getLexicalHandler$72221ad14c43ddef;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setHandler$73980f3327e1b840;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setLexicalHandler$116d9e866e5271e3;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_javax_xml_transform_sax_SAXResult$vmethods {
	struct _jc_object	*(*getHandler$4982bcff61d71265)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
	struct _jc_object	*(*getLexicalHandler$72221ad14c43ddef)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *);
	void	(*setHandler$73980f3327e1b840)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *);
	void	(*setLexicalHandler$116d9e866e5271e3)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *);
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_xml_transform_sax_SAXResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_sax_SAXResult$vmethods	javax_xml_transform_sax_SAXResult;
};

// Vtype
struct _jc_javax_xml_transform_sax_SAXResult$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_sax_SAXResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXResult$sub_refs {
	struct _jc_object	*handler;
	struct _jc_object	*lexicalHandler;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXResult$refs {
    _jc_javax_xml_transform_sax_SAXResult$sub_refs	javax_xml_transform_sax_SAXResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs	javax_xml_transform_sax_SAXResult;
};

// Object instance structure
struct _jc_javax_xml_transform_sax_SAXResult$object {
	_jc_javax_xml_transform_sax_SAXResult$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_sax_SAXResult$vtype	*vtype;
	_jc_javax_xml_transform_sax_SAXResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_sax_SAXResult$vtype _jc_javax_xml_transform_sax_SAXResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_sax_SAXResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_sax_SAXResult$class_object;

#endif	/* _JC_javax_xml_transform_sax_SAXResult_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/sax/SAXResult.h <==
// public class javax.xml.transform.sax.SAXResult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 66f2cec6461d7dc4 javax_xml_transform_sax_SAXResult

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_sax_SAXResult_H_
#define _JC_javax_xml_transform_sax_SAXResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_ContentHandler$object;
struct _jc_org_xml_sax_ext_LexicalHandler$object;

// Typedefs
typedef struct _jc_javax_xml_transform_sax_SAXResult$sub_refs	_jc_javax_xml_transform_sax_SAXResult$sub_refs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs	_jc_javax_xml_transform_sax_SAXResult$sub_nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$refs	_jc_javax_xml_transform_sax_SAXResult$refs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$nonrefs	_jc_javax_xml_transform_sax_SAXResult$nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXResult$object	_jc_javax_xml_transform_sax_SAXResult$object;

typedef struct _jc_javax_xml_transform_sax_SAXResult$fields_struct	_jc_javax_xml_transform_sax_SAXResult$fields_struct;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vmethods	_jc_javax_xml_transform_sax_SAXResult$vmethods;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vtable	_jc_javax_xml_transform_sax_SAXResult$vtable;
typedef const struct _jc_javax_xml_transform_sax_SAXResult$vtype	_jc_javax_xml_transform_sax_SAXResult$vtype;

// Class fields structure
struct _jc_javax_xml_transform_sax_SAXResult$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
};
extern _jc_javax_xml_transform_sax_SAXResult$fields_struct _jc_javax_xml_transform_sax_SAXResult$class_fields;

// Constructors
extern void _jc_javax_xml_transform_sax_SAXResult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_sax_SAXResult$method$_init$f0c7c6098856f091(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXResult$method$getHandler$4982bcff61d71265(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXResult$method$getLexicalHandler$72221ad14c43ddef(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_sax_SAXResult$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_sax_SAXResult$method$setHandler$73980f3327e1b840(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_sax_SAXResult$method$setLexicalHandler$116d9e866e5271e3(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_sax_SAXResult$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getHandler$4982bcff61d71265;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getLexicalHandler$72221ad14c43ddef;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setHandler$73980f3327e1b840;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setLexicalHandler$116d9e866e5271e3;
extern _jc_method _jc_javax_xml_transform_sax_SAXResult$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_javax_xml_transform_sax_SAXResult$vmethods {
	struct _jc_object	*(*getHandler$4982bcff61d71265)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLexicalHandler$72221ad14c43ddef)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *) _JC_JCNI_ATTR;
	void	(*setHandler$73980f3327e1b840)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setLexicalHandler$116d9e866e5271e3)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXResult$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_transform_sax_SAXResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_sax_SAXResult$vmethods	javax_xml_transform_sax_SAXResult;
};

// Vtype
struct _jc_javax_xml_transform_sax_SAXResult$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_sax_SAXResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXResult$sub_refs {
	struct _jc_object	*handler;
	struct _jc_object	*lexicalHandler;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXResult$refs {
    _jc_javax_xml_transform_sax_SAXResult$sub_refs	javax_xml_transform_sax_SAXResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_sax_SAXResult$sub_nonrefs	javax_xml_transform_sax_SAXResult;
};

// Object instance structure
struct _jc_javax_xml_transform_sax_SAXResult$object {
	_jc_javax_xml_transform_sax_SAXResult$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_sax_SAXResult$vtype	*vtype;
	_jc_javax_xml_transform_sax_SAXResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_sax_SAXResult$vtype _jc_javax_xml_transform_sax_SAXResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_sax_SAXResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_sax_SAXResult$class_object;

#endif	/* _JC_javax_xml_transform_sax_SAXResult_H_ */
